@@ -2,14 +2,18 @@
 
 use crate::{DuplexTerminal, ReadTerminal, Terminal, TerminalColorSupport, WriteTerminal};
 use duplex::{Duplex, HalfDuplex};
-use std::{
-    fmt,
-    io::{self, IoSlice, IoSliceMut, Read, Write},
+use std::fmt;
+use std::io::{self, IoSlice, IoSliceMut, Read, Write};
+#[cfg(windows)]
+use unsafe_io::os::windows::{
+    AsRawReadWriteHandleOrSocket, AsReadWriteHandleOrSocket, BorrowedHandleOrSocket,
+    RawHandleOrSocket,
 };
 #[cfg(not(windows))]
-use unsafe_io::os::posish::{AsRawReadWriteFd, RawFd};
-#[cfg(windows)]
-use unsafe_io::os::windows::{AsRawReadWriteHandleOrSocket, RawHandleOrSocket};
+use {
+    io_lifetimes::BorrowedFd,
+    unsafe_io::os::rsix::{AsRawReadWriteFd, AsReadWriteFd, RawFd},
+};
 
 /// A wrapper around a `Read` + `Write` which implements `DuplexTerminal`
 /// but isn't ever a terminal.
@@ -44,6 +48,19 @@ impl<Inner: Duplex + AsRawReadWriteFd> AsRawReadWriteFd for NeverTerminalDuplexe
     }
 }
 
+#[cfg(not(windows))]
+impl<Inner: Duplex + AsReadWriteFd> AsReadWriteFd for NeverTerminalDuplexer<Inner> {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_read_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_write_fd()
+    }
+}
+
 #[cfg(windows)]
 impl<Inner: Duplex + AsRawReadWriteHandleOrSocket> AsRawReadWriteHandleOrSocket
     for NeverTerminalDuplexer<Inner>
@@ -59,6 +76,21 @@ impl<Inner: Duplex + AsRawReadWriteHandleOrSocket> AsRawReadWriteHandleOrSocket
     }
 }
 
+#[cfg(windows)]
+impl<Inner: Duplex + AsReadWriteHandleOrSocket> AsReadWriteHandleOrSocket
+    for NeverTerminalDuplexer<Inner>
+{
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_read_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_write_handle_or_socket()
+    }
+}
+
 impl<Inner: Duplex> Terminal for NeverTerminalDuplexer<Inner> {}
 
 impl<Inner: Duplex + Read> ReadTerminal for NeverTerminalDuplexer<Inner> {
