@@ -1,14 +1,17 @@
 //! The `NeverTerminalWriter` struct.
 
 use crate::{Terminal, TerminalColorSupport, WriteTerminal};
-use std::{
-    fmt,
-    io::{self, IoSlice, Write},
+use std::fmt;
+use std::io::{self, IoSlice, Write};
+#[cfg(windows)]
+use unsafe_io::os::windows::{
+    AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
 };
 #[cfg(not(windows))]
-use unsafe_io::os::posish::{AsRawFd, RawFd};
-#[cfg(windows)]
-use unsafe_io::os::windows::{AsRawHandleOrSocket, RawHandleOrSocket};
+use {
+    io_lifetimes::{AsFd, BorrowedFd},
+    unsafe_io::os::rsix::{AsRawFd, RawFd},
+};
 
 /// A wrapper around a `Write` which implements `WriteTerminal` but isn't ever
 /// a terminal.
@@ -38,6 +41,14 @@ impl<Inner: Write + AsRawFd> AsRawFd for NeverTerminalWriter<Inner> {
     }
 }
 
+#[cfg(not(windows))]
+impl<Inner: Write + AsFd> AsFd for NeverTerminalWriter<Inner> {
+    #[inline]
+    fn as_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_fd()
+    }
+}
+
 #[cfg(windows)]
 impl<Inner: Write + AsRawHandleOrSocket> AsRawHandleOrSocket for NeverTerminalWriter<Inner> {
     #[inline]
@@ -46,6 +57,14 @@ impl<Inner: Write + AsRawHandleOrSocket> AsRawHandleOrSocket for NeverTerminalWr
     }
 }
 
+#[cfg(windows)]
+impl<Inner: Write + AsHandleOrSocket> AsHandleOrSocket for NeverTerminalWriter<Inner> {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_handle_or_socket()
+    }
+}
+
 impl<Inner: Write> Terminal for NeverTerminalWriter<Inner> {}
 
 impl<Inner: Write> WriteTerminal for NeverTerminalWriter<Inner> {
